PCB Environment: DSNParserBase Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Protected Member Functions | Protected Attributes
DSNParserBase Class Referenceabstract

## Public Member Functions
| DSNParserBase (dsn::Data &)
virtual bool | parse (const std::string &)=0

## Protected Member Functions
bool | checkQuote (char c)
void | resetQuote ()
int | isBracket (char c) const
int | checkBracket (char c)
size_t | nextBracket (const std::string &, int dir)
size_t | skipspace (const std::string &, size_t pos) const
size_t | skipspaceRev (const std::string &, size_t minPos, size_t pos) const
std::vector< std::string > | gather (const std::string &, const char *name, const int depth=1)
std::vector< std::string > | gatherArray (const std::string &)
std::vector< Token > | tokenize (const std::string &)
Token | firstToken (const std::string &, size_t *from=0)
std::string | unquote (const std::string &) const
std::string | unquotePin (const std::string &)
std::string | noHyphen (std::string) const
int | unitToExp10 (const std::string &) const
char | parseSide (const std::string &) const

## Protected Attributes
dsn::Data & | mData
char | mStringQuote {0}
char | mEscapeChar {0}
bool | mQuoteOpen {false}
bool | mEscapeActive {false}

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSNParserBase.hpp